# Open Swiss Model Context Protocol

[generated image Karpathy style about Data Connecting]
[labels: testing, pypi, stars, forks...]

[short description of what this project is about key goals and objectif]
-> clean, simple, scalable MCP servers for open swiss data
->

## Usage

## Contributing

We want to scale!

* keep things as simple as possible -> toward AI generated pages keep things in single file
* keep things as standard as possible (TOOLS, TOOLS_HANDLER) and follow the guidelines for what should be a tool, what should be a resource...
* keep it as low as possible in external dependencies (weigh always pros / cons of integrating a new dependency with always a bias toward not adding it)
* keep things formatted with ruff
* keep things tested with pytest
* use typehints and pydantic model for input output of api requests

## Roadmap

data extension
1. integrate as many sources as possible from opendata.swiss

framework extension
1. add support for 

## References
* Model Context Protocol (Anthropic)